@@ -8,8 +8,6 @@ from datetime import datetime, time, timedelta
 from typing import TYPE_CHECKING, Any, Literal, TypedDict
 from zoneinfo import ZoneInfo
 
-from doppyler.model.sound import SoundPreset
-
 from ..const import (
     ATTR_ALARM_SOUNDS,
     ATTR_ALARMS,
@@ -47,12 +45,13 @@ from ..const import (
     ATTR_WEATHER_WAKE_UP_TIME,
     ATTR_WIFI,
 )
-from ..exceptions import ExpiredNonce
+from ..exceptions import ExpiredNonce, InvalidAlarmSound
 from .alarm import Alarm
 from .color import Color
 from .light_bar import LightbarDisplayEffect
 from .main_display_text import MainDisplayText
 from .mini_display_number import MiniDisplayNumber
+from .sound import SoundPreset
 from .weather import WeatherConfiguration, WeatherMode
 from .wifi import WifiStatus
 
@@ -140,6 +139,7 @@ class Doppler:
         self.device_info = DopplerDeviceInfo(device_info)
         self.local_info = DopplerLocalInfo(local_info)
         self.local_control = local_control
+        self.alarm_sounds: list[str] = []
 
         # Set local path
         self.local_path = f"https://{self.local_info.ip_address}:{self.local_info.port}"
@@ -365,6 +365,8 @@ class Doppler:
 
     async def add_alarm(self, alarm: Alarm) -> list[Alarm]:
         """Add new alarm."""
+        if self.alarm_sounds and alarm.sound not in self.alarm_sounds:
+            raise InvalidAlarmSound(self, alarm.sound)
         data = alarm.to_dict()
         alarms = await self._call_api("alarms", "POST", data)
         return sorted(
@@ -753,4 +755,7 @@ class Doppler:
         keys, coros = zip(*data_mapping)
         # Executes all functions and joins the result with the key in a tuple so we can
         # create a dict from it
-        return {key: result for key, result in zip(keys, await asyncio.gather(*coros))}
+        data = {key: result for key, result in zip(keys, await asyncio.gather(*coros))}
+        self.alarm_sounds.clear()
+        self.alarm_sounds.extend(data[ATTR_ALARM_SOUNDS])
+        return data
